@@ -65,6 +65,13 @@ sub read_in {
                 require Config::INI::Reader;
                 $data = Config::INI::Reader->read_string($filecontent);
         }
+        elsif ($intype eq "cfggeneral") {
+                require Config::General;
+                my %data = Config::General->new(-String => $filecontent,
+                                                -InterPolateVars => 1,
+                                               )->getall;
+                $data = \%data;
+        }
         elsif ($intype eq "dumper") {
                 eval '$data = my '.$filecontent;
         }
@@ -127,7 +134,7 @@ sub write_out {
     }
 }
 
-sub run {
+sub execute {
         my ($self, $opt, $args) = @_;
 
         my $path    = $args->[0];
@@ -163,7 +170,7 @@ Writes out the result set according to format.
 
 =head2 opt_spec
 
-=head2 run
+=head2 execute
 
 =head2 validate_args
 
